==> compton-conf_0.14.1.orig.tar.xz: compton-conf-0.14.1/translations/compton-conf_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Paramétrage des effets spéciaux</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Rayon de flou des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Décalage gauche des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Décalage haut des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Transparence des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Couleur de l&apos;ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Correction de quelques bizarreries avec des fenêtres ARGB (codage des couleurs avec gestion de l&apos;opacité)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Zéro la partie du masque de l&apos;ombre derrière la fenêtre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Ne pas dessiner des ombres sur les fenêtres DND</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Éviter de tirer des ombres sur les fenêtres Dock ou tableau de bord</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Activer les ombres côté client, sur les fenêtres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Éviter de tirer ombre sur toutes les fenêtres formées</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Rogner l&apos;ombre des fenêtres maximisées de l&apos;affichage étendu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Opacité</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Opacité pour les menus</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Opacité par défaut des fenêtres inactives</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Opacité par défaut des fenêtres actives</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Opacité des barres de titre et des bordures</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender backend: Taille des étapes pour les images alpha
(Les augmenter pourrait entraîner une moindre utilisation des ressources X)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Assombrir les fenêtres inactives</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Ne pas laisser la luminosité se régler en fonction de l&apos;opacité de la fenêtre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Un fond flou pour les fenêtres transparentes</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Également un fond flou des fenêtres opaques avec des bordures transparentes</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Ne pas laisser le rayon de flou s&apos;ajuster en fonction de l&apos;opacité de la fenêtre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Fondu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Faire un fondu des fenêtres pendant le changement d&apos;opacité</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Durée, en ms, entre les étapes d&apos;un fondu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Changement d&apos;opacité entre les étapes lors du fondu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Variation d&apos;opacité entre les étapes d&apos;un fondu sortant</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Évitez les fenêtres qui s&apos;estompent lors de l&apos;ouverture / la fermeture</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Application d&apos;arrière-plan de rendu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>Extension OpenGL (GLX)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>à propos de ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - outil de configuration de compton

Copyright (C) 2013
Auteur: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> compton-conf_0.16.0.orig.tar.xz: compton-conf-0.16.0/translations/compton-conf_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Paramétrage des effets spéciaux</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Rayon de flou des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Décalage gauche des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Décalage haut des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Transparence des ombres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Couleur de l&apos;ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Correction de quelques bizarreries avec des fenêtres ARGB (codage des couleurs avec gestion de l&apos;opacité)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Zéro la partie du masque de l&apos;ombre derrière la fenêtre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Ne pas dessiner des ombres sur les fenêtres DND</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Éviter de tirer des ombres sur les fenêtres Dock ou tableau de bord</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Activer les ombres côté client, sur les fenêtres</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Éviter de tirer ombre sur toutes les fenêtres formées</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Rogner l&apos;ombre des fenêtres maximisées de l&apos;affichage étendu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Opacité</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Opacité pour les menus</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Opacité par défaut des fenêtres inactives</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Opacité par défaut des fenêtres actives</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Opacité des barres de titre et des bordures</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender backend: Taille des étapes pour les images alpha
(Les augmenter pourrait entraîner une moindre utilisation des ressources X)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Assombrir les fenêtres inactives</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Ne pas laisser la luminosité se régler en fonction de l&apos;opacité de la fenêtre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Un fond flou pour les fenêtres transparentes</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Également un fond flou des fenêtres opaques avec des bordures transparentes</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Ne pas laisser le rayon de flou s&apos;ajuster en fonction de l&apos;opacité de la fenêtre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Fondu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Faire un fondu des fenêtres pendant le changement d&apos;opacité</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Durée, en ms, entre les étapes d&apos;un fondu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Changement d&apos;opacité entre les étapes lors du fondu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Variation d&apos;opacité entre les étapes d&apos;un fondu sortant</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Éviter les fenêtres qui s&apos;estompent lors de l&apos;ouverture/la fermeture</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Application d&apos;arrière-plan de rendu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>Extension OpenGL (GLX)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>à propos de ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - outil de configuration de compton

Copyright (C) 2013
Auteur: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
